=========
Profanity
=========

.. image:: https://travis-ci.org/EnTeQuAk/unfromm.png?branch=master
        :target: https://travis-ci.org/EnTeQuAk/unfromm

.. image:: https://badge.fury.io/py/unfromm.png
    :target: http://badge.fury.io/py/unfromm
